Base58Address class abstract

Base class for all addresses that use base58: P2PKHAddress and P2SHAddress.

Implemented types
Implementers

Constructors

Base58Address.fromString(String encoded, Network network)
factory

Properties

hash → Uint8List
no setter
hashCode → int
The hash code for this object.
no setterinherited
program → Program
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int
The network and address type version of the address
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited