Bech32Address class abstract

Base class for addresses that use bech32: P2WPKHAddress and P2WSHAddress. Unknown witness programs are encoded via UnknownWitnessAddress.

Implemented types
Implementers

Constructors

Bech32Address.fromString(String encoded, Network network)
factory

Properties

data → Uint8List
The "witness program" data encoded in the address
no setter
hashCode → int
The hash code for this object.
no setterinherited
hrp → String
The human readable part of the address used to specify the network
final
program → Program
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int
The program version of the address
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

maxWitnessProgramLength → const int