ECDSAInputSignature class

Encapsulates an ECDSA signature and hashType for inclusion in an Input.

Implemented types

Constructors

ECDSAInputSignature(ECDSASignature signature, [SigHashType hashType = const SigHashType.all()])
ECDSAInputSignature.fromBytes(Uint8List bytes)
factory

Properties

bytes → Uint8List
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
hashType → SigHashType
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signature → ECDSASignature
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited