HDKey class abstract

Implementers

Constructors

HDKey.decode(String b58, {int? privVersion, int? pubVersion})
Decodes a base58 string into a HDPrivateKey or HDPublicKey. May throw InvalidBase58, InvalidBase58Checksum or InvalidHDKey. If privVersion or/and pubVersion is provided, it shall require that the version is equal to either one of these for a corresponsing private or public key or else it shall throw InvalidHDKeyVersion.
factory

Properties

chaincode → Uint8List
no setter
depth → int
final
fingerprint → int
The integer fingerprint of the identifier
no setter
hashCode → int
The hash code for this object.
no setterinherited
identifier → Uint8List
The identifier hash for this key
no setter
index → int
final
parentFingerprint → int
final
privateKey → ECPrivateKey?
no setter
publicKey → ECPublicKey
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

derive(int index) → HDKey
Derives a key at index returning the same type of key: either public or private. The index can inlcude the hardenBit to specify that it is hardened.
deriveHardened(int index) → HDPrivateKey
Derives a hardened key at index which only applies to private keys. The index must not include the left-bit to specify that it is hardened.
derivePath(String path) → HDKey
Derives a child key in a path format akin to "m/15/3'/4" where the optional "m" specifies that this key is a master key and "'" specifies that an index is a hardened key.
encode(int version) → String
Encodes the base58 representation of this key using the version prefix.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

encodedLength → const int
hardenBit → const int
maxIndex → const int