InputCandidate class

A candidate input to spend a UTXO with the UTXO value

Constructors

InputCandidate({required Input input, required BigInt value})

Properties

hashCode → int
The hash code for this object.
no setterinherited
input → Input
Input that can spend the UTXO
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → BigInt
Value of UTXO to be spent
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited