MagicHash class

Mixed-in types

Constructors

MagicHash(String message, String prefix)

Properties

hash → Uint8List
no setter
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
prefix → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
Obtains the cached size of the object
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → Uint8List
Obtains a cached Uint8List with data serialized for this object
inherited
toHex() → String
inherited
toString() → String
A string representation of this object.
inherited
write(Writer writer) → void
Override to write data into writer
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited