Network class

Constructors

Network({required int wifPrefix, required int p2pkhPrefix, required int p2shPrefix, required int privHDPrefix, required int pubHDPrefix, required String bech32Hrp, required String messagePrefix, required BigInt minFee, required BigInt minOutput, required BigInt feePerKb})

Properties

bech32Hrp → String
final
feePerKb → BigInt
final
hashCode → int
The hash code for this object.
no setterinherited
messagePrefix → String
final
minFee → BigInt
final
minOutput → BigInt
final
p2pkhPrefix → int
final
p2shPrefix → int
final
privHDPrefix → int
final
pubHDPrefix → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wifPrefix → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

mainnet → Network
final
testnet → Network
final