OutOfData class

Thrown when attempting to read or write beyond the boundary of data

Implemented types

Constructors

OutOfData(int position, int readLength, int bytesLength)

Properties

bytesLength → int
final
hashCode → int
The hash code for this object.
no setterinherited
position → int
final
readLength → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited