OutPoint class

Reference to an Output by transaction hash and index

Mixed-in types

Constructors

OutPoint(Uint8List hash, int n)
OutPoint.fromHex(String hash, int n)
Takes the reversed transaction hash as hex
OutPoint.fromReader(BytesReader reader)

Properties

coinbase → bool
True if this out point is the type found in a coinbase
no setter
hash → Uint8List
no setter
hashCode → int
The hash code for this object.
no setteroverride
n → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
Obtains the cached size of the object
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → Uint8List
Obtains a cached Uint8List with data serialized for this object
inherited
toHex() → String
inherited
toString() → String
A string representation of this object.
inherited
write(Writer writer) → void
Override to write data into writer
override

Operators

operator ==(Object other) → bool
The equality operator.
override