P2PKHAddress class

Inheritance

Constructors

P2PKHAddress.fromHash(Uint8List hash, {required int version})
Takes a hash directly for a P2PKH address
P2PKHAddress.fromPublicKey(ECPublicKey pubkey, {required int version})
Constructs a P2PKH address from a given pubkey.

Properties

hash → Uint8List
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
program → P2PKH
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int
The network and address type version of the address
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited