P2TR class

Pay-to-Taproot program taking a 32-byte Taproot tweaked key.

Inheritance

Constructors

P2TR.decompile(Uint8List compiled)
P2TR.fromAsm(String asm)
P2TR.fromScript(Script script)
Construct using an output script.
P2TR.fromTaproot(Taproot taproot)
Creates a P2TR program from a Taproot object.
P2TR.fromTweakedKey(ECPublicKey tweakedKey)
Creates a P2TR program with a given tweakedKey.
P2TR.fromTweakedKeyX(Uint8List tweakedKeyX)
Creates a P2TR program with the 32-byte X-only tweaked public key.

Properties

data → Uint8List
The data of the "witness program". It is called "data" and not "program" to avoid confusion with the more general Program class.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
script → Script
finalinherited
tweakedKey → ECPublicKey
no setter
version ↔ int
latefinalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited