P2WPKH class

Pay-to-Witness-Public-Key-Hash program taking a 20-byte public key hash that can satisfy this script with a signature provided as witness data.

Inheritance

Properties

data → Uint8List
The data of the "witness program". It is called "data" and not "program" to avoid confusion with the more general Program class.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
pkHash → Uint8List
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
script → Script
finalinherited
version ↔ int
latefinalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited