P2WPKHAddress class

Inheritance

Constructors

P2WPKHAddress.fromHash(Uint8List hash, {required String hrp})
Constructs a P2WPKH address directly from the hash
P2WPKHAddress.fromPublicKey(ECPublicKey pubkey, {required String hrp})
Constructs a P2WPKH address from a pubkey

Properties

data → Uint8List
The "witness program" data encoded in the address
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hrp → String
The human readable part of the address used to specify the network
finalinherited
program → P2WPKH
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int
The program version of the address
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited