P2WSHAddress class

Inheritance

Constructors

P2WSHAddress.fromHash(Uint8List hash, {required String hrp})
Constructs a P2WSH address from the script hash
P2WSHAddress.fromWitnessScript(Script script, {required String hrp})
Constructs a P2WSH address for a witnessScript

Properties

data → Uint8List
The "witness program" data encoded in the address
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hrp → String
The human readable part of the address used to specify the network
finalinherited
program → P2WSH
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int
The program version of the address
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited