P2Witness class

Arbitrary witness program

Implemented types
Implementers

Constructors

P2Witness.decompile(Uint8List compiled)
P2Witness.fromAsm(String asm)
P2Witness.fromData(int version, Uint8List data)
Creates a non-specific segwit program from "witness program" data.
P2Witness.fromScript(Script script)

Properties

data → Uint8List
The data of the "witness program". It is called "data" and not "program" to avoid confusion with the more general Program class.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
script → Script
final
version ↔ int
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited