ScriptOp class abstract

Represents a single operation or script pushdata

Implementers

Constructors

ScriptOp.fromAsm(String asm)
Interpret a single script ASM string into a ScriptOp.
factory
ScriptOp.fromNumber(int n)
Constructs an ScriptOp from a number, returning the smallest representation
factory
ScriptOp.fromReader(BytesReader reader, {bool requireMinimal = false})
Reads a single operation from a BytesReader. OutOfData will be thrown if there is not enough data to read. If requireMinimal is true, a pushdata operation must be encoded minimally or else PushDataNotMinimal will be thrown.
factory

Properties

asm → String
The ASM string representation of this operation
no setter
compiled → Uint8List
The compiled bytes for this operation
no setter
ecdsaSig → ECDSAInputSignature?
If this is a pushdata of an ECDSA input signature then it shall be returned, or null
no setter
hashCode → int
The hash code for this object.
no setterinherited
number → int?
Returns an integer if the operation pushes a number, or null
no setter
publicKey → ECPublicKey?
If this is a pushdata of a public key then it shall be returned, or null
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schnorrSig → SchnorrInputSignature?
If this is a pushdata of a Schnorr input signature then it shall be returned, or null
no setter

Methods

match(ScriptOp other) → bool
Returns true when the other ScriptOp matches this one. ScriptPushDataMatcher will match with a push data of a particular size.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

op1 → int
final
op16 → int
final
op1Negate → int
final
pushData1 → int
final
pushData2 → int
final
pushData4 → int
final
pushdataMatcherRegExp → RegExp
final