ScriptPushDataMatcher class

Provides comparison with ScriptPushData of a particular size.

Implemented types

Constructors

ScriptPushDataMatcher(int size)

Properties

asm → String
The ASM string representation of this operation
no setteroverride
compiled → Uint8List
The compiled bytes for this operation
no setteroverride
ecdsaSig → ECDSAInputSignature?
If this is a pushdata of an ECDSA input signature then it shall be returned, or null
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
number → int?
Returns an integer if the operation pushes a number, or null
no setteroverride
publicKey → ECPublicKey?
If this is a pushdata of a public key then it shall be returned, or null
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schnorrSig → SchnorrInputSignature?
If this is a pushdata of a Schnorr input signature then it shall be returned, or null
no setteroverride
size → int
final

Methods

match(ScriptOp other) → bool
Returns true when the other ScriptOp matches this one. ScriptPushDataMatcher will match with a push data of a particular size.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited