TapBranch class

Takes two child nodes within the MAST tree.

Implemented types

Constructors

TapBranch(TapNode l, TapNode r)

Properties

hash → Uint8List
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
l → TapNode
final
r → TapNode
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

branchHash → Uint8List Function(Uint8List msg)
final