TapLeaf class

A leaf in the MAST tree representing the Tapscript script.

Implemented types
Mixed-in types

Constructors

TapLeaf(Script script)

Properties

hash → Uint8List
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
script → Script
final
size → int
Obtains the cached size of the object
no setterinherited
version → int
The Tapscript version is fixed as 0xc0 as this is the only implemented and enforced version
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → Uint8List
Obtains a cached Uint8List with data serialized for this object
inherited
toHex() → String
inherited
toString() → String
A string representation of this object.
inherited
write(Writer writer) → void
Override to write data into writer
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

leafHash → Uint8List Function(Uint8List msg)
final

Constants

tapscriptVersion → const int