UnknownWitnessAddress class

This address type is for all bech32 addresses that do not match known witness versions.

Inheritance

Constructors

UnknownWitnessAddress(Uint8List data, {required int version, required String hrp})
Constructs a bech32 witness address from the "witness program" data, witness version and hrp
UnknownWitnessAddress.fromHex(String hex, {required int version, required String hrp})
Constructs a bech32 witness address with the "witness program" data provided as a hex string.

Properties

data → Uint8List
The "witness program" data encoded in the address
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hrp → String
The human readable part of the address used to specify the network
finalinherited
program → P2Witness
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int
The program version of the address
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited