Writable mixin

Classes that use this mixin are serializable to a Writer via write and return cached bytes via toBytes. These classes should be immutable as the bytes are written to only once.

Mixin applications

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
Obtains the cached size of the object
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → Uint8List
Obtains a cached Uint8List with data serialized for this object
toHex() → String
toString() → String
A string representation of this object.
inherited
write(Writer writer) → void
Override to write data into writer

Operators

operator ==(Object other) → bool
The equality operator.
inherited